@@ -86,6 +86,10 @@ class LootBotApi:
     def get_craft_needed(self,item_id):
         return self.__request_url(f"{self.endpoint}/crafts/{item_id}/needed")
 
+    def get_craft_needed_base(self,item_id):
+        craft_needed = self.get_craft_needed(item_id)
+        return list(filter(lambda item : not item.craftable,craft_needed))
+
     def get_craft_used(self,item_id):
         return self.__request_url(f"{self.endpoint}/crafts/{item_id}/used")
 
@@ -112,7 +116,6 @@ class LootBotApi:
                 if element_needed.craftable: steps_list.extend(get_crafting(element_needed.id))
             return steps_list
 
-        
         element = self.get_exact_item(item).id
         craft_list = get_crafting(element)
         craft_list.reverse()
@@ -135,3 +138,17 @@ class LootBotApi:
                 results.append(dict_craft)
 
         return results
+
+    def get_craft_total_needed_base_items(self,item,num_elements=1):
+        def get_crafting(elemento):
+            elements_needed = self.get_craft_needed(elemento)
+            base_elements = self.get_craft_needed_base(elemento)
+
+            for element_needed in elements_needed:
+                if element_needed.craftable:
+                     base_elements.extend(get_crafting(element_needed.id))
+
+            return base_elements
+
+        # TODO: Aggiungere il numero degli elementi mancanti
+        return get_crafting(self.get_exact_item(item).id)
